Statistics » Consultant-led Referral to Treatment Waiting Times Data 2023-24
Author: Statistics

Skip to main content

# Cookies on the NHS England website

We've put some small files called cookies on your device to make our site work. We'd also like to use analytics cookies. These send information about how our site is used to a service called Google Analytics. We use this information to improve our site. Let us know if this is OK. We'll use a cookie to save your choice. You can read more about our cookies before you choose.

# Consultant-led Referral to Treatment Waiting Times Data 2023-24

Click here to return to main RTT page

- If you are interested in England level or regional waiting times please use the “Commissioner Data” files.
- If you are interested in waiting times at provider trusts then please use the “Provider Data” files.

- - Incomplete pathways are waiting times for cases where patients are still waiting to start treatment at the end of the month.
  - Admitted pathways are waiting times for cases where patients completed their RTT pathway during the month with an inpatient/day case admission for treatment. Until September 2015 adjustments were made to admitted pathways for clock pauses, where a patient had declined reasonable offers of admission and chose to wait longer.
  - Non-admitted pathways are waiting times for cases where patients completed their RTT pathway during the month for reasons other than an inpatient/day case admission for treatment (e.g. started treatment in an outpatient setting or a non-treatment clock stop).
  - Incomplete pathways with a decision to admit for treatment are waiting times for cases where patients are still waiting to start treatment at the end of the month where a clinical decision to admit to a hospital bed for treatment has been made.
  - New RTT periods are the number of new RTT pathways where the clock start date is within the reporting month.

Revisions are published periodically (usually every six months) in line with NHS England Analytical Service team’s revisions policy. Referral to treatment data for October 2022 to March 2023 was revised on 10th August 2023. Data for May 2023, and July 2023 to September 2023 was revised on 11th January 2024. Data for October 2023 to March 2024 was revised on 11th July 2024.

Apr23 | May23 | Jun23 | Jul23 | Aug23 | Sep23
Oct23 | Nov23 | Dec23 | Jan24 | Feb24 | Mar24

### March 2024

Incomplete Commissioner Mar24 (XLSX, 4228K) revised
Incomplete Provider Mar24 (XLSX, 8416K) revised

Admitted Commissioner Mar24 (XLSX, 1914K) revised
NonAdmitted Commissioner Mar24 (XLSX, 2041K) revised
New Periods Commissioner Mar24 (XLSX, 149K) revised

Admitted Provider Mar24 (XLSX, 4167K) revised
NonAdmitted Provider Mar24 (XLSX, 4224K) revised
New Periods Provider Mar24 (XLSX, 325K) revised

Full CSV data file Mar24 (ZIP, 3832K) revised

### February 2024

Incomplete Commissioner Feb24 (XLSX, 4248K) revised
Incomplete Provider Feb24 (XLSX, 8517K) revised

Admitted Commissioner Feb24 (XLSX, 1915K)
NonAdmitted Commissioner Feb24 (XLSX, 2051K) revised
New Periods Commissioner Feb24 (XLSX, 154K) revised

Admitted Provider Feb24 (XLSX, 4211K)
NonAdmitted Provider Feb24 (XLSX, 4277K) revised
New Periods Provider Feb24 (XLSX, 334K) revised

Full CSV data file Feb24 (ZIP, 3881K) revised

### January 2024

Incomplete Commissioner Jan24 (XLSX, 4254K)
Incomplete Provider Jan24 (XLSX, 8712K)

Admitted Commissioner Jan24 (XLSX, 1921K) revised
NonAdmitted Commissioner Jan24 (XLSX, 2063K) revised
New Periods Commissioner Jan24 (XLSX, 155K) revised

Admitted Provider Jan24 (XLSX, 4315K) revised
NonAdmitted Provider Jan24 (XLSX, 4387K) revised
New Periods Provider Jan24 (XLSX, 341K) revised

Full CSV data file Jan24 (ZIP, 3943K) revised

### December 2023

Incomplete Commissioner Dec23 (XLSX, 4252K) revised
Incomplete Provider Dec23 (XLSX, 8691K) revised

Admitted Commissioner Dec23 (XLSX, 1462K) revised
NonAdmitted Commissioner Dec23 (XLSX, 2031K) revised
New Periods Commissioner Dec23 (XLSX, 154K) revised

Admitted Provider Dec23 (XLSX, 3194K) revised
NonAdmitted Provider Dec23 (XLSX, 4344K) revised
New Periods Provider Dec23 (XLSX, 340K) revised

Full CSV data file Dec23 (ZIP, 3800K) revised

### November 2023

Incomplete Commissioner Nov23 (XLSX, 4248K) revised
Incomplete Provider Nov23 (XLSX, 8669K) revised

Admitted Commissioner Nov23 (XLSX, 1923K) revised
NonAdmitted Commissioner Nov23 (XLSX, 2065K) revised
New Periods Commissioner Nov23 (XLSX, 154K) revised

Admitted Provider Nov23 (XLSX, 4301K) revised
NonAdmitted Provider Nov23 (XLSX, 4370K) revised
New Periods Provider Nov23 (XLSX, 340K) revised

Full CSV data file Nov23 (ZIP, 3952K) revised

### October 2023

Incomplete Commissioner Oct23 (XLSX, 4256K) revised
Incomplete Provider Oct23 (XLSX, 8664K) revised

Admitted Commissioner Oct23 (XLSX, 1918K) revised
NonAdmitted Commissioner Oct23 (XLSX, 2061K) revised
New Periods Commissioner Oct23 (XLSX, 155K) revised

Admitted Provider Oct23 (XLSX, 4287K) revised
NonAdmitted Provider Oct23 (XLSX, 4359K) revised
New Periods Provider Oct23 (XLSX, 339K) revised

Full CSV data file Oct23 (ZIP, 3928K) revised

### September 2023

Incomplete Commissioner Sep23 (XLSX, 4259K) revised
Incomplete Provider Sep23 (XLSX, 8652K) revised

Admitted Commissioner Sep23 (XLSX, 1912K) revised
NonAdmitted Commissioner Sep23 (XLSX, 2053K) revised
New Periods Commissioner Sep23 (XLSX, 155K) revised

Admitted Provider Sep23 (XLSX, 4272K) revised
NonAdmitted Provider Sep23 (XLSX, 4338K) revised
New Periods Provider Sep23 (XLSX, 339K) revised

Full CSV data file Sep23 (ZIP, 3654K) revised

### August 2023

Incomplete Commissioner Aug23 (XLSX, 4258K) revised
Incomplete Provider Aug23 (XLSX, 8635K) revised

Admitted Commissioner Aug23 (XLSX, 1914K) revised
NonAdmitted Commissioner Aug23 (XLSX, 2047K) revised
New Periods Commissioner Aug23 (XLSX, 155K) revised

Admitted Provider Aug23 (XLSX, 4259K) revised
NonAdmitted Provider Aug23 (XLSX, 4325K) revised
New Periods Provider Aug23 (XLSX, 338K) revised

Full CSV data file Aug23 (ZIP, 3646K) revised

### July 2023

Incomplete Commissioner Jul23 (XLSX, 4250K) revisions
Incomplete Provider Jul23 (XLSX, 8577K) revisions

Admitted Commissioner Jul23 (XLSX, 1906K) revisions
NonAdmitted Commissioner Jul23 (XLSX, 2042K) revisions
New Periods Commissioner Jul23 (XLSX, 149K) revisions

Admitted Provider Jul23 (XLSX, 4229K) revisions
NonAdmitted Provider Jul23 (XLSX, 4294K) revisions
New Periods Provider Jul23 (XLSX, 331K) revisions

Full CSV data file Jul23 (ZIP, 3623K) revised

### June 2023

Incomplete Commissioner Jun23 (XLSX, 4248K)
Incomplete Provider Jun23 (XLSX, 8564K)

Admitted Commissioner Jun23 (XLSX, 1915K)
NonAdmitted Commissioner Jun23 (XLSX, 2051K)
New Periods Commissioner Jun23 (XLSX, 150K)

Admitted Provider Jun23 (XLSX, 4231K)
NonAdmitted Provider Jun23 (XLSX, 4293K)
New Periods Provider Jun23 (XLSX, 330K)

Full CSV data file Jun23 (ZIP, 3659K)

### May 2023

Incomplete Commissioner May23 (XLSX, 4260K) revised
Incomplete Provider May23 (XLSX, 8587K) revised

Admitted Commissioner May23 (XLS, 3875K)
NonAdmitted Commissioner May23 (XLSX, 2055K) revised
New Periods Commissioner May23 (XLSX, 156K) revised

Admitted Provider May23 (XLS, 9535K)
NonAdmitted Provider May23 (XLSX, 4304K) revised
New Periods Provider May23 (XLSX, 336K) revised

Full CSV data file May23 (ZIP, 3627K) revised

### April 2023

Incomplete Commissioner Apr23 (XLS 7462K)
Incomplete Provider Apr23 (XLS, 18344K)

Admitted Commissioner Apr23 (XLS, 3864K)
NonAdmitted Commissioner Apr23 (XLS, 3872K)
New Periods Commissioner Apr23 (XLS, 592K)

Admitted Provider Apr23 (XLS, 9463K)
NonAdmitted Provider Apr23 (XLS, 9487K)
New Periods Provider Apr23 (XLS, 1297K)

Full CSV data file Apr23 (ZIP, 3528K)